@@ -1,7 +1,7 @@
 import uuid
 
-from dv_data_generator.builder.dv_request_builder import DvRequestBuilder, DvRequestTypes
-from dv_data_generator.builder.dv_report_builder import DvReportBuilder
+from dv_data_generator.builders.dv_request_builder import DvEntityStatusTypes, DvRequestBuilder, DvRequestTypes
+from dv_data_generator.builders.dv_report_builder import DvReportBuilder
 
 
 class DvDataDirector:
@@ -11,7 +11,7 @@ class DvDataDirector:
         self._service_account = service_account
         self._debug = debug
 
-    def billable_outcome_report(self) -> DvReportBuilder:
+    def billable_outcome_report(self, **kwargs) -> DvReportBuilder:
         dimensions = [
             "FILTER_ADVERTISER",
             "FILTER_LINE_ITEM_TYPE",
@@ -29,7 +29,7 @@ class DvDataDirector:
 
         builder = (
             DvReportBuilder(credentials=self._credentials,
-                            token=self._token, service_account=self._service_account, debug=self._debug)
+                            token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_title(title)
             .set_dimensions(dimensions)
             .set_metrics(metrics)
@@ -37,7 +37,7 @@ class DvDataDirector:
 
         return builder
 
-    def platform_fee_report(self) -> DvReportBuilder:
+    def platform_fee_report(self, **kwargs) -> DvReportBuilder:
         dimensions = [
             "FILTER_ADVERTISER",
             "FILTER_LINE_ITEM_TYPE",
@@ -54,7 +54,7 @@ class DvDataDirector:
 
         builder = (
             DvReportBuilder(credentials=self._credentials,
-                            token=self._token, service_account=self._service_account, debug=self._debug)
+                            token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_title(title)
             .set_dimensions(dimensions)
             .set_metrics(metrics)
@@ -62,7 +62,7 @@ class DvDataDirector:
 
         return builder
 
-    def spend_report(self) -> DvReportBuilder:
+    def spend_report(self, **kwargs) -> DvReportBuilder:
         dimensions = [
             "FILTER_DATE",
             "FILTER_PARTNER",
@@ -97,7 +97,7 @@ class DvDataDirector:
 
         builder = (
             DvReportBuilder(credentials=self._credentials,
-                            token=self._token, service_account=self._service_account, debug=self._debug)
+                            token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_title(title)
             .set_dimensions(dimensions)
             .set_metrics(metrics)
@@ -105,7 +105,7 @@ class DvDataDirector:
 
         return builder
 
-    def advertisers_report(self) -> DvReportBuilder:
+    def advertisers_report(self, **kwargs) -> DvReportBuilder:
         dimensions = [
             "FILTER_PARTNER_NAME",
             "FILTER_PARTNER",
@@ -122,7 +122,7 @@ class DvDataDirector:
 
         builder = (
             DvReportBuilder(credentials=self._credentials,
-                            token=self._token, service_account=self._service_account, debug=self._debug)
+                            token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_title(title)
             .set_dimensions(dimensions)
             .set_metrics(metrics)
@@ -130,38 +130,57 @@ class DvDataDirector:
 
         return builder
 
-    def partner_list(self) -> DvRequestBuilder:
+    def partner_list(self, **kwargs) -> DvRequestBuilder:
         request_type = DvRequestTypes.LIST_PARTNERS
         builder = (
             DvRequestBuilder(credentials=self._credentials,
-                             token=self._token, debug=self._debug)
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_request_type(request_type)
         )
         return builder
 
-    def partner_list_of_ids(self) -> DvRequestBuilder:
+    def partner_list_of_ids(self, **kwargs) -> DvRequestBuilder:
         request_type = DvRequestTypes.LIST_PARTNER_IDS
         builder = (
             DvRequestBuilder(credentials=self._credentials,
-                             token=self._token, debug=self._debug)
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_request_type(request_type)
         )
         return builder
 
-    def advertiser_list(self) -> DvRequestBuilder:
+    def advertiser_list(self, **kwargs) -> DvRequestBuilder:
         request_type = DvRequestTypes.LIST_ADVERTISER
         builder = (
             DvRequestBuilder(credentials=self._credentials,
-                             token=self._token, debug=self._debug)
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_request_type(request_type)
         )
         return builder
 
-    def advertiser_list_of_ids(self) -> DvRequestBuilder:
+    def advertiser_list_of_ids(self, **kwargs) -> DvRequestBuilder:
         request_type = DvRequestTypes.LIST_ADVERTISER_IDS
         builder = (
             DvRequestBuilder(credentials=self._credentials,
-                             token=self._token, debug=self._debug)
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
             .set_request_type(request_type)
         )
         return builder
+
+    def active_lineitem_list(self, **kwargs) -> DvRequestBuilder:
+        request_type = DvRequestTypes.LIST_LINEITEM
+        builder = (
+            DvRequestBuilder(credentials=self._credentials,
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
+            .set_request_type(request_type)
+        )
+        return builder
+
+    def paused_lineitem_list(self, **kwargs) -> DvRequestBuilder:
+        request_type = DvRequestTypes.LIST_LINEITEM
+        builder = (
+            DvRequestBuilder(credentials=self._credentials,
+                             token=self._token, service_account=self._service_account, debug=self._debug, **kwargs)
+            .set_request_type(request_type)
+            .set_entity_status(DvEntityStatusTypes.PAUSED)
+        )
+        return builder
