@@ -1,7 +1,7 @@
 import unittest
 
 from dv_data_generator.dv_data_director import DvDataDirector
-from dv_data_generator.builder.dv_request_builder import DvRequestTypes
+from dv_data_generator.builders.dv_request_builder import DvRequestTypes
 
 
 class DirectorTests(unittest.TestCase):
